/// <reference types="@types/google.maps" />
import { ReactNode } from 'react';
import { themeList } from './themeList';
interface ILatLng {
    lat: number;
    lng: number;
}
interface IPlace {
    location: ILatLng;
    address: string;
    address_components: google.maps.GeocoderAddressComponent[];
}
interface ThemableMap {
    theme?: keyof typeof themeList;
    className?: string;
}
interface SelectPointMapProps extends ThemableMap {
    initialCenter?: {
        center: {
            lat: number;
            lng: number;
        };
        zoom: number;
    };
    onCenterChange?: (center: IPlace) => void | Promise<void>;
    onMoved?: (center: ILatLng | undefined) => void;
    onButtonClick?: (center: IPlace) => void;
    copies?: {
        searchPlaceholder?: string;
        unknownAddress?: string;
        address?: string;
        lat?: string;
        lng?: string;
        verify?: ReactNode;
    };
    disableCenter?: boolean;
    verifyPositionClassName?: string;
    infoPanel?: boolean;
    enableAutoComplete?: boolean;
    disableSearch?: boolean;
}
interface SelectPointMapPropsV2 extends ThemableMap {
    initialCenter?: {
        center: {
            lat: number;
            lng: number;
        };
        zoom: number;
    };
    onCenterChange?: (center: IPlace) => void | Promise<void>;
    onMoved?: (center: ILatLng | undefined) => void;
    onButtonClick?: (center: IPlace) => void;
    copies?: {
        searchPlaceholder?: string;
        unknownAddress?: string;
        address?: string;
        lat?: string;
        lng?: string;
        verify?: ReactNode;
        city?: string;
    };
    disableCenter?: boolean;
    verifyPositionClassName?: string;
    infoPanel?: boolean;
    disableSearch?: boolean;
    search: (input: {
        address: string;
        city_id: string | number;
    }) => Promise<google.maps.LatLngLiteral>;
    citiesList: {
        id: string | number;
        name: string;
    }[];
}
interface ShowRouteMapProps extends ThemableMap {
    points: Array<ILatLng>;
    timeAndDistanceCallback?: (timeAndDistance: {
        distance: number;
        time: number;
    }) => void;
    onlyPoints?: boolean;
    infoPanel?: boolean;
    copies: {
        distance: string;
        time: string;
    };
}
declare type MapProps = {
    apiKey: string;
    language?: 'es-419' | 'en';
    region?: 'CO' | 'CL' | 'MX' | 'US';
} & (({
    type: 'selectPoint';
} & SelectPointMapProps) | ({
    type: 'selectPointV2';
} & SelectPointMapPropsV2) | ({
    type: 'showRoute';
} & ShowRouteMapProps));
export type { ILatLng, IPlace, SelectPointMapProps, SelectPointMapPropsV2, ShowRouteMapProps, MapProps, };
