/// <reference types="react" />
import { DragUpdate } from '@hello-pangea/dnd';
import { Column, ColumnInstance, HeaderGroup, Row, TableBodyPropGetter, TableBodyProps, TablePropGetter, TableState, TableProps as ReactTableProps, FilterProps, ColumnInterface } from 'react-table';
interface TableType<T extends object = {}> {
    (props: TableProps<T>): JSX.Element;
    ColumnsFilter: () => JSX.Element;
    Country: (props: {
        value: string;
    }) => JSX.Element;
    Currency: (props: {
        value: number;
        locale?: string;
        currency?: string;
        decimals?: number;
    }) => JSX.Element;
    DataTable: (props: {
        className?: string;
    }) => JSX.Element;
    Date: (props: {
        value: string;
    }) => JSX.Element;
    DefaultColumnFilter: <T extends object>(props: FilterProps<T>) => JSX.Element;
    ExportButton: () => JSX.Element;
    GlobalFilter: () => JSX.Element;
    TimeToService: (props: {
        original: any;
        value: any;
    }) => JSX.Element;
}
interface ITableCopies {
    notRegister: string;
    download: string;
    search: string;
    searchLarge: string;
}
interface TableProps<T extends object> {
    children: React.ReactNode;
    tableData: Array<T>;
    tableColumns: Array<Column<T> & ColumnInterface<T>>;
    rowClickHandler?: (row: Row<T>) => React.MouseEventHandler;
    columnFilters?: boolean;
    copies?: ITableCopies;
    className?: string;
}
interface ITableContext<T extends object = any> extends ITableCopies {
    allColumns: ColumnInstance<T>[];
    getTableProps: (propGetter?: TablePropGetter<T> | undefined) => ReactTableProps;
    headerGroups: HeaderGroup<T>[];
    getTableBodyProps: (propGetter?: TableBodyPropGetter<T> | undefined) => TableBodyProps;
    rows: Row<T>[];
    preGlobalFilteredRows: Row<T>[];
    setGlobalFilter: (filterValue: any) => void;
    prepareRow: (row: Row<T>) => void;
    onDragEnd: (result: DragUpdate) => {
        tableData: T[];
        tableColumns: T[];
    } | undefined;
    exportData: any;
    state: TableState<T>;
    rowClickHandler?: (row: Row<T>) => React.MouseEventHandler<Element>;
    columnFilters: boolean;
}
declare const defaultTypes: {
    copies: {
        notRegister: string;
        download: string;
        search: string;
        searchLarge: string;
    };
};
export { defaultTypes };
export type { TableType, TableProps, ITableContext };
